@@ -674,13 +674,13 @@ void RDocumentInterface::updateAllEntities() {
  * Regenerates all scenes attached to this document interface by exporting
  * the document into them.
  */
-void RDocumentInterface::regenerateScenes(bool undone) {
+void RDocumentInterface::regenerateScenes(bool undone, bool invisible) {
     if (!allowUpdate) {
         return;
     }
 
     for (int i=0; i<scenes.length(); i++) {
-        scenes[i]->regenerate(undone);
+        scenes[i]->regenerate(undone, invisible);
     }
 }
 
@@ -2248,6 +2248,7 @@ void RDocumentInterface::objectChangeEvent(RTransaction& transaction) {
     bool layoutHasChanged = false;
     bool viewHasChanged = false;
     bool entityHasChanged = false;
+    bool entityDeleted = false;
 
     QList<RObject::Id> objectIds = transaction.getAffectedObjects();
 
@@ -2337,6 +2338,9 @@ void RDocumentInterface::objectChangeEvent(RTransaction& transaction) {
         if (!entity.isNull()) {
             entityHasChanged = true;
             entityIdsToRegenerate.insert(entity->getId());
+            if (entity->isUndone()) {
+                entityDeleted = true;
+            }
             continue;
         }
 
@@ -2459,7 +2463,22 @@ void RDocumentInterface::objectChangeEvent(RTransaction& transaction) {
 
     if (/*layerHasChanged ||*/ !changedLayerIds.isEmpty() || blockHasChanged || linetypeHasChanged) {
         if (allowRegeneration) {
-            regenerateScenes(true);
+            // this also regenerates the views:
+            if (!changedLayerIds.isEmpty()) {
+                // also export invisible entities (e.g. layer color changed of invisible layer):
+                regenerateScenes(false, true);
+            }
+            else {
+                if (entityDeleted) {
+                    // entity deleted: regen to update reference points:
+                    regenerateScenes(entityIdsToRegenerate, false);
+                    regenerateViews(entityIdsToRegenerate);
+                }
+                else {
+                    regenerateScenes(false, false);
+                }
+            }
+            return;
         }
         else {
             regenerateScenes(entityIdsToRegenerate, false);
