@@ -25,6 +25,9 @@
 #include "RLinetypeListImperial.h"
 #include "RUnit.h"
 
+QMap<unsigned int, QRgb> RDxfServices::aci;
+QMap<QRgb, unsigned int> RDxfServices::revAci;
+
 RDxfServices::RDxfServices() :
     version2GotDIMZIN(false),
     version2GotDIMAZIN(false),
@@ -44,13 +47,13 @@ void RDxfServices::reset() {
 void RDxfServices::fixVersion2String(QString& str) const {
     // correct stacked text
     // \S+0.1\-0.1; -> \S+0.1^-0.1;
-    QRegExp rx("\\\\S([^\\\\;]*)\\\\([^;]*);");
+    QRegularExpression rx("\\\\S([^\\\\;]*)\\\\([^;]*);");
     str.replace(rx, "\\S\\1^\\2;");
 }
 
 void RDxfServices::fixDimensionLabel(QString& text, QString& uTol, QString& lTol) const {
     // strip away initial vertical alignment, e.g. '\A1;'
-    QRegExp rxAlignment("^\\\\A(\\d+);");
+    QRegularExpression rxAlignment("^\\\\A(\\d+);");
     text.replace(rxAlignment, "");
 
     // analyze and strip stacked text (tolerance) at end:
@@ -150,7 +153,7 @@ void RDxfServices::detectVersion2Format(const QString& fileName) {
 
 QString RDxfServices::getSafeBlockName(QString& blockName) {
     QString ret = blockName;
-    ret.replace(QRegExp("[<>/\":;?*|,=`\\\\\n]"), "_");
+    ret.replace(QRegularExpression("[<>/\":;?*|,=`\\\\\n]"), "_");
     ret.replace(QChar(0x0083), "_");
     return ret;
 }
@@ -159,7 +162,7 @@ void RDxfServices::fixBlockName(QString& blockName) {
     // fix invalid block names (mainly from QCAD 2):
     if (!blockName.startsWith("*")) {
         QString oldBlockName = blockName;
-        blockName.replace(QRegExp("[<>/\":;?*|,=`\\\\\n]"), "_");
+        blockName.replace(QRegularExpression("[<>/\":;?*|,=`\\\\\n]"), "_");
         blockName.replace(QChar(0x0083), "_");
         version2BlockMapping.insert(oldBlockName, blockName);
     }
@@ -168,7 +171,7 @@ void RDxfServices::fixBlockName(QString& blockName) {
 void RDxfServices::fixLayerName(QString& layerName) {
     // fix invalid layer names (mainly from QCAD 2):
     QString oldLayerName = layerName;
-    layerName.replace(QRegExp("[<>/\":;?*|,=`\\\\\n]"), "_");
+    layerName.replace(QRegularExpression("[<>/\":;?*|,=`\\\\\n]"), "_");
     layerName.replace(QChar(0x0083), "_");
     version2LayerMapping.insert(oldLayerName, layerName);
 }
@@ -2308,3 +2311,543 @@ int RDxfServices::getFileQCADVersion(const RDocument& doc) {
 #endif
     return fileVersionMajor*100*100*100 + fileVersionMinor*100*100 + fileVersionPatch*100 + fileVersionRev;
 }
+
+void RDxfServices::initAci() {
+    if (!aci.isEmpty()) {
+        return;
+    }
+
+    // fill in ACI:
+    aci.insert(1, qRgb(255, 0, 0));
+    aci.insert(2, qRgb(255, 255, 0));
+    aci.insert(3, qRgb(0, 255, 0));
+    aci.insert(4, qRgb(0, 255, 255));
+    aci.insert(5, qRgb(0, 0, 255));
+    aci.insert(6, qRgb(255, 0, 255));
+    aci.insert(7, qRgb(255, 255, 255));
+    aci.insert(8, qRgb(128, 128, 128));
+    aci.insert(9, qRgb(192, 192, 192));
+
+    //aci.insert(10, qRgb( 255, 0, 0));
+    aci.insert(11, qRgb( 255, 127, 127));
+    aci.insert(12, qRgb( 165, 0, 0));
+    aci.insert(13, qRgb( 165, 82, 82));
+    aci.insert(14, qRgb( 127, 0, 0));
+    aci.insert(15, qRgb( 127, 63, 63));
+    aci.insert(16, qRgb( 76, 0, 0));
+    aci.insert(17, qRgb( 76, 38, 38));
+    aci.insert(18, qRgb( 38, 0, 0));
+    aci.insert(19, qRgb( 38, 19, 19));
+    aci.insert(20, qRgb( 255, 63, 0));
+    aci.insert(21, qRgb( 255, 159, 127));
+    aci.insert(22, qRgb( 165, 41, 0));
+    aci.insert(23, qRgb( 165, 103, 82));
+    aci.insert(24, qRgb( 127, 31, 0));
+    aci.insert(25, qRgb( 127, 79, 63));
+    aci.insert(26, qRgb( 76, 19, 0));
+    aci.insert(27, qRgb( 76, 47, 38));
+    aci.insert(28, qRgb( 38, 9, 0));
+    aci.insert(29, qRgb( 38, 23, 19));
+    aci.insert(30, qRgb( 255, 127, 0));
+    aci.insert(31, qRgb( 255, 191, 127));
+    aci.insert(32, qRgb( 165, 82, 0));
+    aci.insert(33, qRgb( 165, 124, 82));
+    aci.insert(34, qRgb( 127, 63, 0));
+    aci.insert(35, qRgb( 127, 95, 63));
+    aci.insert(36, qRgb( 76, 38, 0));
+    aci.insert(37, qRgb( 76, 57, 38));
+    aci.insert(38, qRgb( 38, 19, 0));
+    aci.insert(39, qRgb( 38, 28, 19));
+    aci.insert(40, qRgb( 255, 191, 0));
+    aci.insert(41, qRgb( 255, 223, 127));
+    aci.insert(42, qRgb( 165, 124, 0));
+    aci.insert(43, qRgb( 165, 145, 82));
+    aci.insert(44, qRgb( 127, 95, 0));
+    aci.insert(45, qRgb( 127, 111, 63));
+    aci.insert(46, qRgb( 76, 57, 0));
+    aci.insert(47, qRgb( 76, 66, 38));
+    aci.insert(48, qRgb( 38, 28, 0));
+    aci.insert(49, qRgb( 38, 33, 19));
+    //aci.insert(50, qRgb( 255, 255, 0));
+    aci.insert(51, qRgb( 255, 255, 127));
+    aci.insert(52, qRgb( 165, 165, 0));
+    aci.insert(53, qRgb( 165, 165, 82));
+    aci.insert(54, qRgb( 127, 127, 0));
+    aci.insert(55, qRgb( 127, 127, 63));
+    aci.insert(56, qRgb( 76, 76, 0));
+    aci.insert(57, qRgb( 76, 76, 38));
+    aci.insert(58, qRgb( 38, 38, 0));
+    aci.insert(59, qRgb( 38, 38, 19));
+    aci.insert(60, qRgb( 191, 255, 0));
+    aci.insert(61, qRgb( 223, 255, 127));
+    aci.insert(62, qRgb( 124, 165, 0));
+    aci.insert(63, qRgb( 145, 165, 82));
+    aci.insert(64, qRgb( 95, 127, 0));
+    aci.insert(65, qRgb( 111, 127, 63));
+    aci.insert(66, qRgb( 57, 76, 0));
+    aci.insert(67, qRgb( 66, 76, 38));
+    aci.insert(68, qRgb( 28, 38, 0));
+    aci.insert(69, qRgb( 33, 38, 19));
+    aci.insert(70, qRgb( 127, 255, 0));
+    aci.insert(71, qRgb( 191, 255, 127));
+    aci.insert(72, qRgb( 82, 165, 0));
+    aci.insert(73, qRgb( 124, 165, 82));
+    aci.insert(74, qRgb( 63, 127, 0));
+    aci.insert(75, qRgb( 95, 127, 63));
+    aci.insert(76, qRgb( 38, 76, 0));
+    aci.insert(77, qRgb( 57, 76, 38));
+    aci.insert(78, qRgb( 19, 38, 0));
+    aci.insert(79, qRgb( 28, 38, 19));
+    aci.insert(80, qRgb( 63, 255, 0));
+    aci.insert(81, qRgb( 159, 255, 127));
+    aci.insert(82, qRgb( 41, 165, 0));
+    aci.insert(83, qRgb( 103, 165, 82));
+    aci.insert(84, qRgb( 31, 127, 0));
+    aci.insert(85, qRgb( 79, 127, 63));
+    aci.insert(86, qRgb( 19, 76, 0));
+    aci.insert(87, qRgb( 47, 76, 38));
+    aci.insert(88, qRgb( 9, 38, 0));
+    aci.insert(89, qRgb( 23, 38, 19));
+    //aci.insert(90, qRgb( 0, 255, 0));
+    aci.insert(91, qRgb( 127, 255, 127));
+    aci.insert(92, qRgb( 0, 165, 0));
+    aci.insert(93, qRgb( 82, 165, 82));
+    aci.insert(94, qRgb( 0, 127, 0));
+    aci.insert(95, qRgb( 63, 127, 63));
+    aci.insert(96, qRgb( 0, 76, 0));
+    aci.insert(97, qRgb( 38, 76, 38));
+    aci.insert(98, qRgb( 0, 38, 0));
+    aci.insert(99, qRgb( 19, 38, 19));
+    aci.insert(100, qRgb( 0, 255, 63));
+    aci.insert(101, qRgb( 127, 255, 159));
+    aci.insert(102, qRgb( 0, 165, 41));
+    aci.insert(103, qRgb( 82, 165, 103));
+    aci.insert(104, qRgb( 0, 127, 31));
+    aci.insert(105, qRgb( 63, 127, 79));
+    aci.insert(106, qRgb( 0, 76, 19));
+    aci.insert(107, qRgb( 38, 76, 47));
+    aci.insert(108, qRgb( 0, 38, 9));
+    aci.insert(109, qRgb( 19, 38, 23));
+    aci.insert(110, qRgb( 0, 255, 127));
+    aci.insert(111, qRgb( 127, 255, 191));
+    aci.insert(112, qRgb( 0, 165, 82));
+    aci.insert(113, qRgb( 82, 165, 124));
+    aci.insert(114, qRgb( 0, 127, 63));
+    aci.insert(115, qRgb( 63, 127, 95));
+    aci.insert(116, qRgb( 0, 76, 38));
+    aci.insert(117, qRgb( 38, 76, 57));
+    aci.insert(118, qRgb( 0, 38, 19));
+    aci.insert(119, qRgb( 19, 38, 28));
+    aci.insert(120, qRgb( 0, 255, 191));
+    aci.insert(121, qRgb( 127, 255, 223));
+    aci.insert(122, qRgb( 0, 165, 124));
+    aci.insert(123, qRgb( 82, 165, 145));
+    aci.insert(124, qRgb( 0, 127, 95));
+    aci.insert(125, qRgb( 63, 127, 111));
+    aci.insert(126, qRgb( 0, 76, 57));
+    aci.insert(127, qRgb( 38, 76, 66));
+    aci.insert(128, qRgb( 0, 38, 28));
+    aci.insert(129, qRgb( 19, 38, 33));
+    //aci.insert(130, qRgb( 0, 255, 255));
+    aci.insert(131, qRgb( 127, 255, 255));
+    aci.insert(132, qRgb( 0, 165, 165));
+    aci.insert(133, qRgb( 82, 165, 165));
+    aci.insert(134, qRgb( 0, 127, 127));
+    aci.insert(135, qRgb( 63, 127, 127));
+    aci.insert(136, qRgb( 0, 76, 76));
+    aci.insert(137, qRgb( 38, 76, 76));
+    aci.insert(138, qRgb( 0, 38, 38));
+    aci.insert(139, qRgb( 19, 38, 38));
+    aci.insert(140, qRgb( 0, 191, 255));
+    aci.insert(141, qRgb( 127, 223, 255));
+    aci.insert(142, qRgb( 0, 124, 165));
+    aci.insert(143, qRgb( 82, 145, 165));
+    aci.insert(144, qRgb( 0, 95, 127));
+    aci.insert(145, qRgb( 63, 111, 127));
+    aci.insert(146, qRgb( 0, 57, 76));
+    aci.insert(147, qRgb( 38, 66, 76));
+    aci.insert(148, qRgb( 0, 28, 38));
+    aci.insert(149, qRgb( 19, 33, 38));
+    aci.insert(150, qRgb( 0, 127, 255));
+    aci.insert(151, qRgb( 127, 191, 255));
+    aci.insert(152, qRgb( 0, 82, 165));
+    aci.insert(153, qRgb( 82, 124, 165));
+    aci.insert(154, qRgb( 0, 63, 127));
+    aci.insert(155, qRgb( 63, 95, 127));
+    aci.insert(156, qRgb( 0, 38, 76));
+    aci.insert(157, qRgb( 38, 57, 76));
+    aci.insert(158, qRgb( 0, 19, 38));
+    aci.insert(159, qRgb( 19, 28, 38));
+    aci.insert(160, qRgb( 0, 63, 255));
+    aci.insert(161, qRgb( 127, 159, 255));
+    aci.insert(162, qRgb( 0, 41, 165));
+    aci.insert(163, qRgb( 82, 103, 165));
+    aci.insert(164, qRgb( 0, 31, 127));
+    aci.insert(165, qRgb( 63, 79, 127));
+    aci.insert(166, qRgb( 0, 19, 76));
+    aci.insert(167, qRgb( 38, 47, 76));
+    aci.insert(168, qRgb( 0, 9, 38));
+    aci.insert(169, qRgb( 19, 23, 38));
+    //aci.insert(170, qRgb( 0, 0, 255));
+    aci.insert(171, qRgb( 127, 127, 255));
+    aci.insert(172, qRgb( 0, 0, 165));
+    aci.insert(173, qRgb( 82, 82, 165));
+    aci.insert(174, qRgb( 0, 0, 127));
+    aci.insert(175, qRgb( 63, 63, 127));
+    aci.insert(176, qRgb( 0, 0, 76));
+    aci.insert(177, qRgb( 38, 38, 76));
+    aci.insert(178, qRgb( 0, 0, 38));
+    aci.insert(179, qRgb( 19, 19, 38));
+    aci.insert(180, qRgb( 63, 0, 255));
+    aci.insert(181, qRgb( 159, 127, 255));
+    aci.insert(182, qRgb( 41, 0, 165));
+    aci.insert(183, qRgb( 103, 82, 165));
+    aci.insert(184, qRgb( 31, 0, 127));
+    aci.insert(185, qRgb( 79, 63, 127));
+    aci.insert(186, qRgb( 19, 0, 76));
+    aci.insert(187, qRgb( 47, 38, 76));
+    aci.insert(188, qRgb( 9, 0, 38));
+    aci.insert(189, qRgb( 23, 19, 38));
+    aci.insert(190, qRgb( 127, 0, 255));
+    aci.insert(191, qRgb( 191, 127, 255));
+    aci.insert(192, qRgb( 82, 0, 165));
+    aci.insert(193, qRgb( 124, 82, 165));
+    aci.insert(194, qRgb( 63, 0, 127));
+    aci.insert(195, qRgb( 95, 63, 127));
+    aci.insert(196, qRgb( 38, 0, 76));
+    aci.insert(197, qRgb( 57, 38, 76));
+    aci.insert(198, qRgb( 19, 0, 38));
+    aci.insert(199, qRgb( 28, 19, 38));
+    aci.insert(200, qRgb( 191, 0, 255));
+    aci.insert(201, qRgb( 223, 127, 255));
+    aci.insert(202, qRgb( 124, 0, 165));
+    aci.insert(203, qRgb( 145, 82, 165));
+    aci.insert(204, qRgb( 95, 0, 127));
+    aci.insert(205, qRgb( 111, 63, 127));
+    aci.insert(206, qRgb( 57, 0, 76));
+    aci.insert(207, qRgb( 66, 38, 76));
+    aci.insert(208, qRgb( 28, 0, 38));
+    aci.insert(209, qRgb( 33, 19, 38));
+    //aci.insert(210, qRgb( 255, 0, 255));
+    aci.insert(211, qRgb( 255, 127, 255));
+    aci.insert(212, qRgb( 165, 0, 165));
+    aci.insert(213, qRgb( 165, 82, 165));
+    aci.insert(214, qRgb( 127, 0, 127));
+    aci.insert(215, qRgb( 127, 63, 127));
+    aci.insert(216, qRgb( 76, 0, 76));
+    aci.insert(217, qRgb( 76, 38, 76));
+    aci.insert(218, qRgb( 38, 0, 38));
+    aci.insert(219, qRgb( 38, 19, 38));
+    aci.insert(220, qRgb( 255, 0, 191));
+    aci.insert(221, qRgb( 255, 127, 223));
+    aci.insert(222, qRgb( 165, 0, 124));
+    aci.insert(223, qRgb( 165, 82, 145));
+    aci.insert(224, qRgb( 127, 0, 95));
+    aci.insert(225, qRgb( 127, 63, 111));
+    aci.insert(226, qRgb( 76, 0, 57));
+    aci.insert(227, qRgb( 76, 38, 66));
+    aci.insert(228, qRgb( 38, 0, 28));
+    aci.insert(229, qRgb( 38, 19, 33));
+    aci.insert(230, qRgb( 255, 0, 127));
+    aci.insert(231, qRgb( 255, 127, 191));
+    aci.insert(232, qRgb( 165, 0, 82));
+    aci.insert(233, qRgb( 165, 82, 124));
+    aci.insert(234, qRgb( 127, 0, 63));
+    aci.insert(235, qRgb( 127, 63, 95));
+    aci.insert(236, qRgb( 76, 0, 38));
+    aci.insert(237, qRgb( 76, 38, 57));
+    aci.insert(238, qRgb( 38, 0, 19));
+    aci.insert(239, qRgb( 38, 19, 28));
+    aci.insert(240, qRgb( 255, 0, 63));
+    aci.insert(241, qRgb( 255, 127, 159));
+    aci.insert(242, qRgb( 165, 0, 41));
+    aci.insert(243, qRgb( 165, 82, 103));
+    aci.insert(244, qRgb( 127, 0, 31));
+    aci.insert(245, qRgb( 127, 63, 79));
+    aci.insert(246, qRgb( 76, 0, 19));
+    aci.insert(247, qRgb( 76, 38, 47));
+    aci.insert(248, qRgb( 38, 0, 9));
+    aci.insert(249, qRgb( 38, 19, 23));
+    aci.insert(250, qRgb( 84, 84, 84));
+    aci.insert(251, qRgb( 118, 118, 118));
+    aci.insert(252, qRgb( 152, 152, 152));
+    aci.insert(253, qRgb( 186, 186, 186));
+    aci.insert(254, qRgb( 220, 220, 220));
+    //aci.insert(255, qRgb( 255, 255, 255));
+
+    revAci.insert(qRgb(255, 0, 0), 1);
+    revAci.insert(qRgb(255, 255, 0), 2);
+    revAci.insert(qRgb(0, 255, 0), 3);
+    revAci.insert(qRgb(0, 255, 255), 4);
+    revAci.insert(qRgb(0, 0, 255), 5);
+    revAci.insert(qRgb(255, 0, 255), 6);
+    revAci.insert(qRgb(255, 255, 255), 7);
+    revAci.insert(qRgb(128, 128, 128), 8);
+    revAci.insert(qRgb(192, 192, 192), 9);
+
+    //revAci.insert(qRgb(255, 0, 0), 10);
+    revAci.insert(qRgb(255, 127, 127), 11);
+    revAci.insert(qRgb(165, 0, 0), 12);
+    revAci.insert(qRgb(165, 82, 82), 13);
+    revAci.insert(qRgb(127, 0, 0), 14);
+    revAci.insert(qRgb(127, 63, 63), 15);
+    revAci.insert(qRgb(76, 0, 0), 16);
+    revAci.insert(qRgb(76, 38, 38), 17);
+    revAci.insert(qRgb(38, 0, 0), 18);
+    revAci.insert(qRgb(38, 19, 19), 19);
+    revAci.insert(qRgb(255, 63, 0), 20);
+    revAci.insert(qRgb(255, 159, 127), 21);
+    revAci.insert(qRgb(165, 41, 0), 22);
+    revAci.insert(qRgb(165, 103, 82), 23);
+    revAci.insert(qRgb(127, 31, 0), 24);
+    revAci.insert(qRgb(127, 79, 63), 25);
+    revAci.insert(qRgb(76, 19, 0), 26);
+    revAci.insert(qRgb(76, 47, 38), 27);
+    revAci.insert(qRgb(38, 9, 0), 28);
+    revAci.insert(qRgb(38, 23, 19), 29);
+    revAci.insert(qRgb(255, 127, 0), 30);
+    revAci.insert(qRgb(255, 191, 127), 31);
+    revAci.insert(qRgb(165, 82, 0), 32);
+    revAci.insert(qRgb(165, 124, 82), 33);
+    revAci.insert(qRgb(127, 63, 0), 34);
+    revAci.insert(qRgb(127, 95, 63), 35);
+    revAci.insert(qRgb(76, 38, 0), 36);
+    revAci.insert(qRgb(76, 57, 38), 37);
+    revAci.insert(qRgb(38, 19, 0), 38);
+    revAci.insert(qRgb(38, 28, 19), 39);
+    revAci.insert(qRgb(255, 191, 0), 40);
+    revAci.insert(qRgb(255, 223, 127), 41);
+    revAci.insert(qRgb(165, 124, 0), 42);
+    revAci.insert(qRgb(165, 145, 82), 43);
+    revAci.insert(qRgb(127, 95, 0), 44);
+    revAci.insert(qRgb(127, 111, 63), 45);
+    revAci.insert(qRgb(76, 57, 0), 46);
+    revAci.insert(qRgb(76, 66, 38), 47);
+    revAci.insert(qRgb(38, 28, 0), 48);
+    revAci.insert(qRgb(38, 33, 19), 49);
+    //revAci.insert(qRgb(255, 255, 0), 50);
+    revAci.insert(qRgb(255, 255, 127), 51);
+    revAci.insert(qRgb(165, 165, 0), 52);
+    revAci.insert(qRgb(165, 165, 82), 53);
+    revAci.insert(qRgb(127, 127, 0), 54);
+    revAci.insert(qRgb(127, 127, 63), 55);
+    revAci.insert(qRgb(76, 76, 0), 56);
+    revAci.insert(qRgb(76, 76, 38), 57);
+    revAci.insert(qRgb(38, 38, 0), 58);
+    revAci.insert(qRgb(38, 38, 19), 59);
+    revAci.insert(qRgb(191, 255, 0), 60);
+    revAci.insert(qRgb(223, 255, 127), 61);
+    revAci.insert(qRgb(124, 165, 0), 62);
+    revAci.insert(qRgb(145, 165, 82), 63);
+    revAci.insert(qRgb(95, 127, 0), 64);
+    revAci.insert(qRgb(111, 127, 63), 65);
+    revAci.insert(qRgb(57, 76, 0), 66);
+    revAci.insert(qRgb(66, 76, 38), 67);
+    revAci.insert(qRgb(28, 38, 0), 68);
+    revAci.insert(qRgb(33, 38, 19), 69);
+    revAci.insert(qRgb(127, 255, 0), 70);
+    revAci.insert(qRgb(191, 255, 127), 71);
+    revAci.insert(qRgb(82, 165, 0), 72);
+    revAci.insert(qRgb(124, 165, 82), 73);
+    revAci.insert(qRgb(63, 127, 0), 74);
+    revAci.insert(qRgb(95, 127, 63), 75);
+    revAci.insert(qRgb(38, 76, 0), 76);
+    revAci.insert(qRgb(57, 76, 38), 77);
+    revAci.insert(qRgb(19, 38, 0), 78);
+    revAci.insert(qRgb(28, 38, 19), 79);
+    revAci.insert(qRgb(63, 255, 0), 80);
+    revAci.insert(qRgb(159, 255, 127), 81);
+    revAci.insert(qRgb(41, 165, 0), 82);
+    revAci.insert(qRgb(103, 165, 82), 83);
+    revAci.insert(qRgb(31, 127, 0), 84);
+    revAci.insert(qRgb(79, 127, 63), 85);
+    revAci.insert(qRgb(19, 76, 0), 86);
+    revAci.insert(qRgb(47, 76, 38), 87);
+    revAci.insert(qRgb(9, 38, 0), 88);
+    revAci.insert(qRgb(23, 38, 19), 89);
+    //revAci.insert(qRgb(0, 255, 0), 90);
+    revAci.insert(qRgb(127, 255, 127), 91);
+    revAci.insert(qRgb(0, 165, 0), 92);
+    revAci.insert(qRgb(82, 165, 82), 93);
+    revAci.insert(qRgb(0, 127, 0), 94);
+    revAci.insert(qRgb(63, 127, 63), 95);
+    revAci.insert(qRgb(0, 76, 0), 96);
+    revAci.insert(qRgb(38, 76, 38), 97);
+    revAci.insert(qRgb(0, 38, 0), 98);
+    revAci.insert(qRgb(19, 38, 19), 99);
+    revAci.insert(qRgb(0, 255, 63), 100);
+    revAci.insert(qRgb(127, 255, 159), 101);
+    revAci.insert(qRgb(0, 165, 41), 102);
+    revAci.insert(qRgb(82, 165, 103), 103);
+    revAci.insert(qRgb(0, 127, 31), 104);
+    revAci.insert(qRgb(63, 127, 79), 105);
+    revAci.insert(qRgb(0, 76, 19), 106);
+    revAci.insert(qRgb(38, 76, 47), 107);
+    revAci.insert(qRgb(0, 38, 9), 108);
+    revAci.insert(qRgb(19, 38, 23), 109);
+    revAci.insert(qRgb(0, 255, 127), 110);
+    revAci.insert(qRgb(127, 255, 191), 111);
+    revAci.insert(qRgb(0, 165, 82), 112);
+    revAci.insert(qRgb(82, 165, 124), 113);
+    revAci.insert(qRgb(0, 127, 63), 114);
+    revAci.insert(qRgb(63, 127, 95), 115);
+    revAci.insert(qRgb(0, 76, 38), 116);
+    revAci.insert(qRgb(38, 76, 57), 117);
+    revAci.insert(qRgb(0, 38, 19), 118);
+    revAci.insert(qRgb(19, 38, 28), 119);
+    revAci.insert(qRgb(0, 255, 191), 120);
+    revAci.insert(qRgb(127, 255, 223), 121);
+    revAci.insert(qRgb(0, 165, 124), 122);
+    revAci.insert(qRgb(82, 165, 145), 123);
+    revAci.insert(qRgb(0, 127, 95), 124);
+    revAci.insert(qRgb(63, 127, 111), 125);
+    revAci.insert(qRgb(0, 76, 57), 126);
+    revAci.insert(qRgb(38, 76, 66), 127);
+    revAci.insert(qRgb(0, 38, 28), 128);
+    revAci.insert(qRgb(19, 38, 33), 129);
+    //revAci.insert(qRgb(0, 255, 255), 130);
+    revAci.insert(qRgb(127, 255, 255), 131);
+    revAci.insert(qRgb(0, 165, 165), 132);
+    revAci.insert(qRgb(82, 165, 165), 133);
+    revAci.insert(qRgb(0, 127, 127), 134);
+    revAci.insert(qRgb(63, 127, 127), 135);
+    revAci.insert(qRgb(0, 76, 76), 136);
+    revAci.insert(qRgb(38, 76, 76), 137);
+    revAci.insert(qRgb(0, 38, 38), 138);
+    revAci.insert(qRgb(19, 38, 38), 139);
+    revAci.insert(qRgb(0, 191, 255), 140);
+    revAci.insert(qRgb(127, 223, 255), 141);
+    revAci.insert(qRgb(0, 124, 165), 142);
+    revAci.insert(qRgb(82, 145, 165), 143);
+    revAci.insert(qRgb(0, 95, 127), 144);
+    revAci.insert(qRgb(63, 111, 127), 145);
+    revAci.insert(qRgb(0, 57, 76), 146);
+    revAci.insert(qRgb(38, 66, 76), 147);
+    revAci.insert(qRgb(0, 28, 38), 148);
+    revAci.insert(qRgb(19, 33, 38), 149);
+    revAci.insert(qRgb(0, 127, 255), 150);
+    revAci.insert(qRgb(127, 191, 255), 151);
+    revAci.insert(qRgb(0, 82, 165), 152);
+    revAci.insert(qRgb(82, 124, 165), 153);
+    revAci.insert(qRgb(0, 63, 127), 154);
+    revAci.insert(qRgb(63, 95, 127), 155);
+    revAci.insert(qRgb(0, 38, 76), 156);
+    revAci.insert(qRgb(38, 57, 76), 157);
+    revAci.insert(qRgb(0, 19, 38), 158);
+    revAci.insert(qRgb(19, 28, 38), 159);
+    revAci.insert(qRgb(0, 63, 255), 160);
+    revAci.insert(qRgb(127, 159, 255), 161);
+    revAci.insert(qRgb(0, 41, 165), 162);
+    revAci.insert(qRgb(82, 103, 165), 163);
+    revAci.insert(qRgb(0, 31, 127), 164);
+    revAci.insert(qRgb(63, 79, 127), 165);
+    revAci.insert(qRgb(0, 19, 76), 166);
+    revAci.insert(qRgb(38, 47, 76), 167);
+    revAci.insert(qRgb(0, 9, 38), 168);
+    revAci.insert(qRgb(19, 23, 38), 169);
+    //revAci.insert(qRgb(0, 0, 255), 170);
+    revAci.insert(qRgb(127, 127, 255), 171);
+    revAci.insert(qRgb(0, 0, 165), 172);
+    revAci.insert(qRgb(82, 82, 165), 173);
+    revAci.insert(qRgb(0, 0, 127), 174);
+    revAci.insert(qRgb(63, 63, 127), 175);
+    revAci.insert(qRgb(0, 0, 76), 176);
+    revAci.insert(qRgb(38, 38, 76), 177);
+    revAci.insert(qRgb(0, 0, 38), 178);
+    revAci.insert(qRgb(19, 19, 38), 179);
+    revAci.insert(qRgb(63, 0, 255), 180);
+    revAci.insert(qRgb(159, 127, 255), 181);
+    revAci.insert(qRgb(41, 0, 165), 182);
+    revAci.insert(qRgb(103, 82, 165), 183);
+    revAci.insert(qRgb(31, 0, 127), 184);
+    revAci.insert(qRgb(79, 63, 127), 185);
+    revAci.insert(qRgb(19, 0, 76), 186);
+    revAci.insert(qRgb(47, 38, 76), 187);
+    revAci.insert(qRgb(9, 0, 38), 188);
+    revAci.insert(qRgb(23, 19, 38), 189);
+    revAci.insert(qRgb(127, 0, 255), 190);
+    revAci.insert(qRgb(191, 127, 255), 191);
+    revAci.insert(qRgb(82, 0, 165), 192);
+    revAci.insert(qRgb(124, 82, 165), 193);
+    revAci.insert(qRgb(63, 0, 127), 194);
+    revAci.insert(qRgb(95, 63, 127), 195);
+    revAci.insert(qRgb(38, 0, 76), 196);
+    revAci.insert(qRgb(57, 38, 76), 197);
+    revAci.insert(qRgb(19, 0, 38), 198);
+    revAci.insert(qRgb(28, 19, 38), 199);
+    revAci.insert(qRgb(191, 0, 255), 200);
+    revAci.insert(qRgb(223, 127, 255), 201);
+    revAci.insert(qRgb(124, 0, 165), 202);
+    revAci.insert(qRgb(145, 82, 165), 203);
+    revAci.insert(qRgb(95, 0, 127), 204);
+    revAci.insert(qRgb(111, 63, 127), 205);
+    revAci.insert(qRgb(57, 0, 76), 206);
+    revAci.insert(qRgb(66, 38, 76), 207);
+    revAci.insert(qRgb(28, 0, 38), 208);
+    revAci.insert(qRgb(33, 19, 38), 209);
+    //revAci.insert(qRgb(255, 0, 255), 210);
+    revAci.insert(qRgb(255, 127, 255), 211);
+    revAci.insert(qRgb(165, 0, 165), 212);
+    revAci.insert(qRgb(165, 82, 165), 213);
+    revAci.insert(qRgb(127, 0, 127), 214);
+    revAci.insert(qRgb(127, 63, 127), 215);
+    revAci.insert(qRgb(76, 0, 76), 216);
+    revAci.insert(qRgb(76, 38, 76), 217);
+    revAci.insert(qRgb(38, 0, 38), 218);
+    revAci.insert(qRgb(38, 19, 38), 219);
+    revAci.insert(qRgb(255, 0, 191), 220);
+    revAci.insert(qRgb(255, 127, 223), 221);
+    revAci.insert(qRgb(165, 0, 124), 222);
+    revAci.insert(qRgb(165, 82, 145), 223);
+    revAci.insert(qRgb(127, 0, 95), 224);
+    revAci.insert(qRgb(127, 63, 111), 225);
+    revAci.insert(qRgb(76, 0, 57), 226);
+    revAci.insert(qRgb(76, 38, 66), 227);
+    revAci.insert(qRgb(38, 0, 28), 228);
+    revAci.insert(qRgb(38, 19, 33), 229);
+    revAci.insert(qRgb(255, 0, 127), 230);
+    revAci.insert(qRgb(255, 127, 191), 231);
+    revAci.insert(qRgb(165, 0, 82), 232);
+    revAci.insert(qRgb(165, 82, 124), 233);
+    revAci.insert(qRgb(127, 0, 63), 234);
+    revAci.insert(qRgb(127, 63, 95), 235);
+    revAci.insert(qRgb(76, 0, 38), 236);
+    revAci.insert(qRgb(76, 38, 57), 237);
+    revAci.insert(qRgb(38, 0, 19), 238);
+    revAci.insert(qRgb(38, 19, 28), 239);
+    revAci.insert(qRgb(255, 0, 63), 240);
+    revAci.insert(qRgb(255, 127, 159), 241);
+    revAci.insert(qRgb(165, 0, 41), 242);
+    revAci.insert(qRgb(165, 82, 103), 243);
+    revAci.insert(qRgb(127, 0, 31), 244);
+    revAci.insert(qRgb(127, 63, 79), 245);
+    revAci.insert(qRgb(76, 0, 19), 246);
+    revAci.insert(qRgb(76, 38, 47), 247);
+    revAci.insert(qRgb(38, 0, 9), 248);
+    revAci.insert(qRgb(38, 19, 23), 249);
+    revAci.insert(qRgb(84, 84, 84), 250);
+    revAci.insert(qRgb(118, 118, 118), 251);
+    revAci.insert(qRgb(152, 152, 152), 252);
+    revAci.insert(qRgb(186, 186, 186), 253);
+    revAci.insert(qRgb(220, 220, 220), 254);
+    //revAci.insert(qRgb(255, 255, 255), 255);
+}
+
+int RDxfServices::getAci(const RColor& col) {
+    initAci();
+
+    QRgb key = col.rgb();
+    if (!revAci.contains(key)) {
+        return -1;
+    }
+    return (int)revAci[key];
+}
+
+RColor RDxfServices::getColor(unsigned int index) {
+    initAci();
+
+    if (!aci.contains(index)) {
+        return RColor();
+    }
+    return RColor(QColor::fromRgb(aci[index]));
+}
