@@ -220,6 +220,9 @@ int main(int argc, char *argv[]) {
 
     RSingleApplication* app = new RSingleApplication(appId, argc, argv, guiEnabled);
 
+    // make sure arguments are correctly encoded:
+    RSettings::setOriginalArguments(QCoreApplication::arguments());
+
 #if defined(Q_OS_MAC) || defined(Q_OS_LINUX)
     // note that SIGPIPE is only ignored in release mode, gdb catches SIGPIPE
     // by default. To disable that behavior in gdb, use:
